@@ -11,8 +11,6 @@ use std::cmp::{Eq, Ord, Ordering, PartialEq, PartialOrd, Reverse};
 use std::collections::BinaryHeap;
 use std::sync::Arc;
 
-use smol::channel::TryRecvError::*;
-
 #[derive(Default, Eq, Debug, Copy, Clone)]
 /// recycle unit.
 pub(crate) struct RecycleUnit {
@@ -57,14 +55,17 @@ impl PartialEq for RecycleUnit {
 #[derive(Debug)]
 ///RecyclingBins is resource recycler, excute timeout task-handle.
 pub(crate) struct RecyclingBins {
-    ///storage all task-handle in there.
+    /// storage all task-handle in there.
     recycle_unit_heap: AsyncMutex<BinaryHeap<Reverse<RecycleUnit>>>,
 
     /// use it to recieve source-data build recycle-unit.
-    recycle_unit_sources: AsyncMutex<AsyncReceiver<RecycleUnit>>,
+    recycle_unit_sources: AsyncReceiver<RecycleUnit>,
 
     /// notify timeout-event to event-handler for cancel that.
     timer_event_sender: TimerEventSender,
+
+    /// The runtime kind.
+    runtime_kind: RuntimeKind,
 }
 
 impl RecyclingBins {
@@ -72,38 +73,41 @@ impl RecyclingBins {
     pub(crate) fn new(
         recycle_unit_sources: AsyncReceiver<RecycleUnit>,
         timer_event_sender: TimerEventSender,
+        runtime_kind: RuntimeKind,
     ) -> Self {
         let recycle_unit_heap: AsyncMutex<BinaryHeap<Reverse<RecycleUnit>>> =
             AsyncMutex::new(BinaryHeap::new());
-        let recycle_unit_sources = AsyncMutex::new(recycle_unit_sources);
+        let recycle_unit_sources = recycle_unit_sources;
 
         RecyclingBins {
             recycle_unit_heap,
             recycle_unit_sources,
             timer_event_sender,
+            runtime_kind,
         }
     }
 
     /// alternate run fn between recycle and  add_recycle_unit.
     pub(crate) async fn recycle(self: Arc<Self>) {
-        //get now timestamp
+        // get now timestamp
 
-        //peek inside RecyclingBins has anyone meet contitions.
+        // peek inside RecyclingBins has anyone meet contitions.
 
-        //pop one of recycle_unit_heap, execute it.
+        // pop one of recycle_unit_heap, execute it.
 
         loop {
             let mut recycle_unit_heap = self.recycle_unit_heap.lock().await;
 
             let now: u64 = get_timestamp();
+            let mut duration: Option<Duration> = None;
             for _ in 0..200 {
-                // recv from channel, if no item in channel
-                // drop lock.
-
                 if let Some(recycle_flag) = (&recycle_unit_heap).peek().map(|r| r.0.deadline <= now)
                 {
                     if !recycle_flag {
-                        drop(recycle_unit_heap);
+                        duration = (&recycle_unit_heap)
+                            .peek()
+                            .map(|r| r.0.deadline - now)
+                            .map(Duration::from_secs);
                         break;
                     }
 
@@ -118,13 +122,13 @@ impl RecyclingBins {
 
                 //send msg to event_handle.
                 } else {
-                    drop(recycle_unit_heap);
                     break;
                 }
             }
 
-            yield_now().await;
             //drop lock.
+            drop(recycle_unit_heap);
+            self.yield_for_while(duration).await;
         }
     }
 
@@ -137,25 +141,16 @@ impl RecyclingBins {
 
     pub(crate) async fn add_recycle_unit(self: Arc<Self>) {
         'loopLayer: loop {
-            'forLayer: for _ in 0..200 {
-                let mut recycle_unit_heap = self.recycle_unit_heap.lock().await;
-
-                match self.recycle_unit_sources.lock().await.try_recv() {
+            for _ in 0..200 {
+                match self.recycle_unit_sources.recv().await {
                     Ok(recycle_unit) => {
+                        let mut recycle_unit_heap = self.recycle_unit_heap.lock().await;
                         (&mut recycle_unit_heap).push(Reverse(recycle_unit));
                     }
 
-                    Err(e) => match e {
-                        Empty => {
-                            drop(recycle_unit_heap);
-                            break 'forLayer;
-                        }
-
-                        Closed => {
-                            drop(recycle_unit_heap);
-                            break 'loopLayer;
-                        }
-                    },
+                    Err(_) => {
+                        break 'loopLayer;
+                    }
                 }
             }
 
@@ -163,6 +158,19 @@ impl RecyclingBins {
             // out of scope , recycle_unit_heap is auto-drop;
         }
     }
+
+    pub(crate) async fn yield_for_while(&self, duration: Option<Duration>) {
+        let duration = duration.unwrap_or_else(|| Duration::from_secs(3));
+        match self.runtime_kind {
+            RuntimeKind::Smol => {
+                Timer::after(duration).await;
+            }
+            #[cfg(feature = "tokio-support")]
+            RuntimeKind::Tokio => {
+                sleep_by_tokio(duration).await;
+            }
+        }
+    }
 }
 
 mod tests {
@@ -171,7 +179,7 @@ mod tests {
 
     #[test]
     fn test_task_valid() -> AnyResult<()> {
-        use super::{get_timestamp, RecycleUnit, RecyclingBins, TimerEvent};
+        use super::{get_timestamp, RecycleUnit, RecyclingBins, RuntimeKind, TimerEvent};
         use smol::{
             block_on,
             channel::{unbounded, TryRecvError},
@@ -189,8 +197,9 @@ mod tests {
         let recycling_bins = Arc::new(RecyclingBins::new(
             recycle_unit_receiver,
             timer_event_sender,
+            RuntimeKind::Smol,
         ));
-        //TODO:optimize.
+
         thread_spawn(move || {
             block_on(async {
                 recycling_bins
@@ -212,7 +221,7 @@ mod tests {
         if let Err(e) = timer_event_receiver.try_recv() {
             assert_eq!(e, TryRecvError::Empty);
         }
-        park_timeout(Duration::new(3, 3_000_000));
+        park_timeout(Duration::from_secs(4));
 
         for _ in 1..10 {
             assert!(dbg!(timer_event_receiver.try_recv()).is_ok());
